"""
General utils
"""
from hum.utils.plotting import plot_wf, disp_wf

from hum.utils.infinite_waveform import InfiniteWaveform
